Index: sdk/lib/io/directory.dart |
diff --git a/sdk/lib/io/directory.dart b/sdk/lib/io/directory.dart |
index cf9ae48487f727c8fc12578447a84a6dff786e59..f9bcff5c17a2a629e0a17ba2f490c8952e32fead 100644 |
--- a/sdk/lib/io/directory.dart |
+++ b/sdk/lib/io/directory.dart |
@@ -134,19 +134,29 @@ abstract class Directory extends FileSystemEntity { |
* Lists the sub-directories and files of this [Directory]. |
* Optionally recurses into sub-directories. |
* |
+ * If [followLinks] is false, then any symbolic links found |
+ * are reported as links, rather than as directories or files, |
+ * and are not recursed into. |
+ * |
* The result is a stream of [FileSystemEntity] objects |
* for the directories and files. |
*/ |
- Stream<FileSystemEntity> list({bool recursive: false}); |
+ Stream<FileSystemEntity> list({bool recursive: false, |
+ bool followLinks: true}); |
/** |
* Lists the sub-directories and files of this [Directory]. |
* Optionally recurses into sub-directories. |
* |
+ * If [followLinks] is false, then any symbolic links found |
+ * are reported as links, rather than as directories or files, |
+ * and are not recursed into. |
+ * |
* Returns a [List] containing [FileSystemEntity] objects for the |
* directories and files. |
*/ |
- List<FileSystemEntity> listSync({bool recursive: false}); |
+ List<FileSystemEntity> listSync({bool recursive: false, |
+ bool followLinks: true}); |
/** |
* Returns a human readable string for this Directory instance. |
@@ -134,19 +134,29 @@ abstract class Directory extends FileSystemEntity { |
* The result is a stream of [FileSystemEntity] objects |
- * for the directories and files. |
+ * for the directories, files, and links. |
*/ |
@@ -134,19 +134,29 @@ abstract class Directory extends FileSystemEntity { |
* Returns a [List] containing [FileSystemEntity] objects for the |
- * directories and files. |
+ * directories, files, and links. |
*/ |